==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/AllowedRoutesFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AllowedRoutesFluent<A extends AllowedRoutesFluent<A>> extends Fluent<A>{
  public A addToKinds(Integer index,RouteGroupKind item);
  public A setToKinds(Integer index,RouteGroupKind item);
  public A addToKinds(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteGroupKind... items);
  public A addAllToKinds(Collection<RouteGroupKind> items);
  public A removeFromKinds(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteGroupKind... items);
  public A removeAllFromKinds(Collection<RouteGroupKind> items);
  public A removeMatchingFromKinds(Predicate<RouteGroupKindBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildKinds instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteGroupKind> getKinds();
  public List<RouteGroupKind> buildKinds();
  public RouteGroupKind buildKind(Integer index);
  public RouteGroupKind buildFirstKind();
  public RouteGroupKind buildLastKind();
  public RouteGroupKind buildMatchingKind(Predicate<RouteGroupKindBuilder> predicate);
  public Boolean hasMatchingKind(Predicate<RouteGroupKindBuilder> predicate);
  public A withKinds(List<RouteGroupKind> kinds);
  public A withKinds(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteGroupKind... kinds);
  public Boolean hasKinds();
  public A addNewKind(String group,String kind);
  public AllowedRoutesFluent.KindsNested<A> addNewKind();
  public AllowedRoutesFluent.KindsNested<A> addNewKindLike(RouteGroupKind item);
  public AllowedRoutesFluent.KindsNested<A> setNewKindLike(Integer index,RouteGroupKind item);
  public AllowedRoutesFluent.KindsNested<A> editKind(Integer index);
  public AllowedRoutesFluent.KindsNested<A> editFirstKind();
  public AllowedRoutesFluent.KindsNested<A> editLastKind();
  public AllowedRoutesFluent.KindsNested<A> editMatchingKind(Predicate<RouteGroupKindBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNamespaces instead.
   * @return The buildable object.
   */
  @Deprecated
  public RouteNamespaces getNamespaces();
  public RouteNamespaces buildNamespaces();
  public A withNamespaces(RouteNamespaces namespaces);
  public Boolean hasNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> withNewNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> withNewNamespacesLike(RouteNamespaces item);
  public AllowedRoutesFluent.NamespacesNested<A> editNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> editOrNewNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> editOrNewNamespacesLike(RouteNamespaces item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface KindsNested<N> extends Nested<N>,RouteGroupKindFluent<AllowedRoutesFluent.KindsNested<N>>{
    public N and();
    public N endKind();
    
  }
  public interface NamespacesNested<N> extends Nested<N>,RouteNamespacesFluent<AllowedRoutesFluent.NamespacesNested<N>>{
    public N and();
    public N endNamespaces();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/AllowedRoutesFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AllowedRoutesFluent<A extends AllowedRoutesFluent<A>> extends Fluent<A>{
  public A addToKinds(int index,RouteGroupKind item);
  public A setToKinds(int index,RouteGroupKind item);
  public A addToKinds(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteGroupKind... items);
  public A addAllToKinds(Collection<RouteGroupKind> items);
  public A removeFromKinds(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteGroupKind... items);
  public A removeAllFromKinds(Collection<RouteGroupKind> items);
  public A removeMatchingFromKinds(Predicate<RouteGroupKindBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildKinds instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteGroupKind> getKinds();
  public List<RouteGroupKind> buildKinds();
  public RouteGroupKind buildKind(int index);
  public RouteGroupKind buildFirstKind();
  public RouteGroupKind buildLastKind();
  public RouteGroupKind buildMatchingKind(Predicate<RouteGroupKindBuilder> predicate);
  public Boolean hasMatchingKind(Predicate<RouteGroupKindBuilder> predicate);
  public A withKinds(List<RouteGroupKind> kinds);
  public A withKinds(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteGroupKind... kinds);
  public Boolean hasKinds();
  public A addNewKind(String group,String kind);
  public AllowedRoutesFluent.KindsNested<A> addNewKind();
  public AllowedRoutesFluent.KindsNested<A> addNewKindLike(RouteGroupKind item);
  public AllowedRoutesFluent.KindsNested<A> setNewKindLike(int index,RouteGroupKind item);
  public AllowedRoutesFluent.KindsNested<A> editKind(int index);
  public AllowedRoutesFluent.KindsNested<A> editFirstKind();
  public AllowedRoutesFluent.KindsNested<A> editLastKind();
  public AllowedRoutesFluent.KindsNested<A> editMatchingKind(Predicate<RouteGroupKindBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNamespaces instead.
   * @return The buildable object.
   */
  @Deprecated
  public RouteNamespaces getNamespaces();
  public RouteNamespaces buildNamespaces();
  public A withNamespaces(RouteNamespaces namespaces);
  public Boolean hasNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> withNewNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> withNewNamespacesLike(RouteNamespaces item);
  public AllowedRoutesFluent.NamespacesNested<A> editNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> editOrNewNamespaces();
  public AllowedRoutesFluent.NamespacesNested<A> editOrNewNamespacesLike(RouteNamespaces item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface KindsNested<N> extends Nested<N>,RouteGroupKindFluent<AllowedRoutesFluent.KindsNested<N>>{
    public N and();
    public N endKind();
    
  }
  public interface NamespacesNested<N> extends Nested<N>,RouteNamespacesFluent<AllowedRoutesFluent.NamespacesNested<N>>{
    public N and();
    public N endNamespaces();
    
  }
  
}
